.. _following-latest:

=============================
 Following the latest source
=============================

These are the instructions if you just want to follow the latest
ODL source, but you don't need to do any development for now.

The steps are:

* :ref:`install-git`
* Get a local copy of the `ODL GitHub`_ repository.
* Update your local copy from time to time.

Get a local copy of the code
============================

From the command line:

.. code-block:: bash

   $ git clone https://github.com/odlgroup/odl.git

You now have a copy of the code tree in the new ``odl`` directory.

Updating the code
=================

From time to time you may want to pull down the latest code.  Do this with

.. code-block:: bash

   $ cd odl
   $ git pull

The tree in ``odl`` will now have the latest changes from the initial
repository.

.. include:: links.inc
